# BananaBits
[![Gem Version](https://badge.fury.io/rb/banana_bits.svg)](https://badge.fury.io/rb/banana_bits)

BananaBits simplifies some basic methods that are commonly used to manage Mailchimp members and lists with the [Gibbon gem](https://github.com/amro/gibbon).
It allows you to get setup subscribing, unsubscribing, and archiving members in minutes.

## Installation

Add this line to your Gemfile:

```ruby
gem 'banana_bits'
```

And then execute:

    $ bundle

## Usage

This gem can be configured with your Mailchimp credentials in an initializer or they can be passed
in when initializing the client.  You must provide both your API key and the list (audience) id.

```
BananaBits.configure do |config|
  config.api_key = 'your_mailchimp_api_key'
  config.list_id = 'your_mailchimp_list_id'
end
```

```
BananaBits::Client.new(
  'some@email.com',
  api_key: 'your_mailchimp_api_key',
  list_id: 'your_mailchimp_list_id'
)
```

### Methods

#### Subscribe
```
BananaBits::Client.new('test@example.com).subscribe(
  {
    merge_fields: {
      FNAME: 'Test',
      LNAME: 'User'
    }
  }
)
```

#### Unsubscribe
```
BananaBits::Client.new('test@example.com).unsubscribe
```

#### Delete (Archive)
```
BananaBits::Client.new('test@example.com).delete
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `bundle exec rspec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://bitbucket.org/eightbitdevelopers/banana_bits. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

## Code of Conduct

Everyone interacting in the BananaBits project’s codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://bitbucket.org/eightbitdevelopers/banana_bits/src/master/CODE_OF_CONDUCT.md).
